import { DocumentNode, FragmentDefinitionNode, GraphQLEnumType, GraphQLSchema, GraphQLType, OperationDefinitionNode, SelectionSetNode, Source } from "graphql";
import { Dict } from "./util";
declare type ImportData = {
    kind: "all";
} | {
    kind: "some";
    names: string[];
};
export declare function loadGraphQLFromFile(path: string): Source;
export interface ImportedFragment {
    name: string;
    path: string;
    fragment: {
        type: TSType;
        node: FragmentDefinitionNode;
    };
    context: ReturnType<typeof resolveTypesSorted>;
}
export interface ImportsRawData {
    usedNamedTypes: Dict<boolean>;
    fragmentDeps: Dict<string[]>;
    fragments: Dict<{
        type: TSType;
        node: FragmentDefinitionNode;
    }>;
}
export interface Imports {
    loadedImports: ImportedFragment[];
    loadedImportsMap: Dict<ImportedFragment>;
    rawImportData: ImportsRawData[];
    prefixMap: Dict<string>;
    embedImports: boolean;
}
export declare function loadImports(specs: ImportSpec[], includes: string[], schema: GraphQLSchema, embedImports: boolean): Imports;
export interface ImportSpec {
    from: string;
    what: ImportData;
}
export declare function extractImportSpecs(data: string): ImportSpec[];
export declare function logErrorMessage(message: string, fileName: string, lineNumber: number): void;
export declare function validateDocument(schema: GraphQLSchema, document: DocumentNode, allowUnusedFragments: boolean): void;
export declare type TSType = TSObject | TSNamed | TSArray | TSIntersection;
export interface TSIntersection {
    type: "intersection";
    types: TSType[];
    nullable?: boolean;
}
export interface TSObject {
    type: "object";
    fields: Dict<TSType>;
    nullable?: boolean;
    asNamed?: string;
}
export interface TSNamed {
    type: "named";
    name: string;
    nullable?: boolean;
}
export interface TSArray {
    type: "array";
    element: TSType;
    nullable?: boolean;
}
export declare function enumToString(t: GraphQLEnumType, ident?: number): string;
export declare function typeToString(t: TSType, ident?: number, useUndefined?: boolean): string;
export declare function convertType(t: GraphQLType, ss: SelectionSetNode | undefined, fragments: Dict<{
    type: TSType;
}>, imports: Dict<ImportedFragment>, nullable?: boolean, expandNamedInput?: boolean): TSType;
export declare function sortDictValues<T>(d: Dict<T>): {
    name: string;
    value: T;
}[];
export declare function resolveTypesSorted(schema: GraphQLSchema, doc: DocumentNode, imports: Imports | undefined): {
    usedNamedTypes: Dict<boolean>;
    operations: Dict<{
        operation: TSType;
        variables: TSType;
        node: OperationDefinitionNode;
    }>;
    fragments: Dict<{
        type: TSType;
        node: FragmentDefinitionNode;
    }>;
    fragmentDeps: Dict<string[]>;
    usedNamedTypesSorted: {
        name: string;
        value: boolean;
    }[];
    fragmentsSorted: {
        name: string;
        value: {
            type: TSType;
            node: FragmentDefinitionNode;
        };
    }[];
    operationsSorted: {
        name: string;
        value: {
            operation: TSType;
            variables: TSType;
            node: OperationDefinitionNode;
        };
    }[];
};
export declare function walkTSType(t: TSType, cb: (v: TSType) => boolean): boolean | undefined;
export declare function extractNamedTypes(t: TSType, namedTypes: Dict<TSType>): void;
export declare function addFragmentDepsRecursive(deps: Dict<boolean>, frags: string[], fragsMap: Dict<string[]>, imports: Dict<ImportedFragment>, path?: string): void;
export declare function extractFragmentDeps(ss: SelectionSetNode | undefined, deps: Dict<boolean>): void;
export declare function recursiveCopyFragments(schema: GraphQLSchema, usedNamedTypes: Dict<boolean>, dst: Dict<{
    type: TSType;
    node: FragmentDefinitionNode;
}>, src: Dict<{
    type: TSType;
    node: FragmentDefinitionNode;
}>, visited: Dict<boolean>, key: string, deps: Dict<string[]>): void;
export declare function resolveTypes(schema: GraphQLSchema, doc: DocumentNode, imports: Imports | undefined): {
    usedNamedTypes: Dict<boolean>;
    operations: Dict<{
        operation: TSType;
        variables: TSType;
        node: OperationDefinitionNode;
    }>;
    fragments: Dict<{
        type: TSType;
        node: FragmentDefinitionNode;
    }>;
    fragmentDeps: Dict<string[]>;
};
export declare function ensureOperationNamesAreUnique(doc: DocumentNode): DocumentNode;
export {};
